<?php

namespace Drupal\views_entity_link\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\field\EntityLink as EntityLinkBase;

/**
 * Field handler to present a link to an entity using entity link templates.
 *
 * @ViewsField("views_entity_link")
 */
class EntityLink extends EntityLinkBase {

  /**
   * {@inheritdoc}
   */
  public function defineOptions() {
    $options = parent::defineOptions();
    $options['link_template'] = ['default' => ''];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    $def = $this->entityTypeManager->getDefinition($this->definition['entity_type']);
    $templates = array_keys($def->getLinkTemplates());
    $templates = array_combine($templates, $templates);

    $form['link_template'] = [
      '#type' => 'select',
      '#title' => $this->t('Link template'),
      '#default_value' => $this->options['link_template'],
      '#options' => $templates,
      '#required' => TRUE,
    ];

    parent::buildOptionsForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityLinkTemplate() {
    return $this->options['link_template'];
  }

}
